#
# spec file for package gnome-radio
#
# Copyright (c) 2024 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


Name:           gnome-radio
Version:        128
Release:        1.4
Summary:        Live Internet radio broadcaster discovery program
License:        GPL-3.0-or-later
URL:            https://www.gnomeradio.org
Source:         %{name}-%{version}.tar.zst
BuildRequires:  intltool
BuildRequires:  itstool
BuildRequires:  pkgconfig
BuildRequires:  pkgconfig(champlain-gtk-0.12)
BuildRequires:  pkgconfig(geoclue-2.0)
BuildRequires:  pkgconfig(geocode-glib-2.0)
BuildRequires:  pkgconfig(glib-2.0)
BuildRequires:  pkgconfig(gobject-2.0)
BuildRequires:  pkgconfig(gstreamer-1.0)
BuildRequires:  pkgconfig(gstreamer-player-1.0)
BuildRequires:  pkgconfig(gstreamer-plugins-bad-1.0)
BuildRequires:  pkgconfig(gstreamer-plugins-base-1.0)
BuildRequires:  pkgconfig(gstreamer-tag-1.0)
BuildRequires:  pkgconfig(gstreamer-video-1.0)
BuildRequires:  pkgconfig(gtk+-3.0) >= 3.24.34
BuildRequires:  pkgconfig(libgeoclue-2.0)
BuildRequires:  pkgconfig(libxml-2.0)
BuildRequires:  pkgconfig(pangoft2)
Provides:       gnome-internet-radio-locator = %{version}
Obsoletes:      gnome-internet-radio-locator < 16
Provides:       girl < 11
Obsoletes:      girl = %{version}

%description
GNOME Radio is a Free Software program that allows you to easily
locate Free Internet Radio stations by broadcasters on the Internet
with the help of map and text search.  GNOME Radio is developed on
the GNOME desktop platform and it requires at least GStreamer 1.0
for playback.  Enjoy Free Internet Radio.

%lang_package

%prep
%autosetup

%build
%configure
%make_build

%install
%make_install
%find_lang gtk-internet-radio-locator

%files
%license COPYING
%doc ChangeLog README
%{_bindir}/gtk-internet-radio-locator
%{_datadir}/icons/hicolor/*/apps/gtk-internet-radio-locator.*
%{_datadir}/appdata/gtk-internet-radio-locator.appdata.xml
%{_datadir}/applications/gtk-internet-radio-locator.desktop
%{_datadir}/gtk-internet-radio-locator/
%{_mandir}/man1/gtk-internet-radio-locator.1%{?ext_man}

%files lang -f gtk-internet-radio-locator.lang

%changelog
* Wed Sep 11 2024 Dominique Leuenberger <dimstar@opensuse.org>
- Update to version 128
  + internet-radio-locator.xml: Add Radio Haifa.
- Replace pkgconfig(geocode-glib-1.0) BuildRequires with
  pkgconfig(geocode-glib-2.0): follow upstream changes.
* Fri Mar 31 2023 Dominique Leuenberger <dimstar@opensuse.org>
- Update to version 64.0:
  + Stations: Add Radio Punjab Today (New Dehli, India).
- Changes from version 48.0:
  + Stations:
  - Update Echo of Moscow from European Union (Moscow, Russia).
- Changes from version 47.0:
  + GUI: Update KCSN (Los Angeles, California).
  + Stations: Update Radio Eins RBB (Frankfurt, Germany).
* Thu Sep 22 2022 Dominique Leuenberger <dimstar@opensuse.org>
- Update to version 46.0:
  + Minor UI changes.
  + Added radio stations.
  + Revert back to GTK3 (no reason given).
- Replace pkgconfig(gtk4) BuildRequires with pkgconfig(gtk+-3.0),
  following upstream.
* Tue Aug 30 2022 Dominique Leuenberger <dimstar@opensuse.org>
- Update to version 45.1:
  + Stations: add RTI and Radio Free Asia.
- Changes from version 45.0:
  + Build system changes only.
- Changes from version 44.1:
  + BBC World Service profile
- Changes from version 44.0:
  + Initial port to GTK4.
  + Include meson build system.
- Replace pkgconfig(gtk+-3.0) BuildRequires with pkgconfig(gtk4):
  follow upstreams port to GTK4.
* Mon May 30 2022 Dominique Leuenberger <dimstar@opensuse.org>
- Update to version 16.0.43:
  + Add some radio stations from Norway and Denmark.
  + Updated translations.
* Fri Apr  8 2022 Emily Gonyer <emilyyrose@gmail.com>
- Updated to version 16.0.42
  + Build
  - configure.ac: Update for 16.0.42
  - data/gnome-radio.desktop.in.in: Update for 16.0.42
  - data/gnome-radio.desktop.in: Update for 16.0.42
  - data/screenshot.png: Update for 16.0.42
  - gnome-radio.doap: Update for 16.0.42
  - gnome-radio.spec.in: Update for 16.0.42
  + XML: src/gnome-radio.xml: Update for 16.0.42
* Thu Mar 31 2022 Bjørn Lie <bjorn.lie@gmail.com>
- Update to version 16.0.6:
  + Build:
  - configure.ac: Update for gnome-radio 16.0.6
  - gnome-radio.spec.in: Update for gnome-radio 16.0.6
  + GUI: src/gnome-radio.c: New title ("gnome-radio 16.0.6")
  + XML: src/gnome-radio.xml: Update for gnome-radio 16.0.6
- Changes from version 16.0.5:
  + Build:
  - configure.ac: Update for gnome-radio 16.0.5
  - gnome-radio.spec.in: Update for gnome-radio 16.0.5
  + Documentation:
  - data/gnome-radio.desktop.in: Update for gnome-radio 16.0.5
  - data/gnome-radio.desktop.in.in: Update for gnome-radio 16.0.5
  + XML: src/gnome-radio.xml: Update for gnome-radio 16.0.5
* Sun Mar 20 2022 Bjørn Lie <bjorn.lie@gmail.com>
- Update to version 16.0.4:
  + HACKING: Update GNOME_RADIO_DEBUG, uri and program history.
  + THANKS: Update entry for Luna Jernberg.
* Thu Mar 17 2022 Dominique Leuenberger <dimstar@opensuse.org>
- Initial package, version 16.0.3.
